# \DefaultApi

All URIs are relative to *https://api.monobank.ua*

Method | HTTP request | Description
------------- | ------------- | -------------
[**BankCurrencyGet**](DefaultApi.md#BankCurrencyGet) | **Get** /bank/currency | Отримання курсів валют
[**PersonalClientInfoGet**](DefaultApi.md#PersonalClientInfoGet) | **Get** /personal/client-info | Інформація про клієнта
[**PersonalStatementAccountFromToGet**](DefaultApi.md#PersonalStatementAccountFromToGet) | **Get** /personal/statement/{account}/{from}/{to} | Виписка
[**PersonalWebhookPost**](DefaultApi.md#PersonalWebhookPost) | **Post** /personal/webhook | Встановлення WebHook



## BankCurrencyGet

> []CurrencyInfoInner BankCurrencyGet(ctx).Execute()

Отримання курсів валют



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "gitea.stuzer.link/stuzer05/go-monobank"
)

func main() {

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	resp, r, err := apiClient.DefaultApi.BankCurrencyGet(context.Background()).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `DefaultApi.BankCurrencyGet``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
	// response from `BankCurrencyGet`: []CurrencyInfoInner
	fmt.Fprintf(os.Stdout, "Response from `DefaultApi.BankCurrencyGet`: %v\n", resp)
}
```

### Path Parameters

This endpoint does not need any parameter.

### Other Parameters

Other parameters are passed through a pointer to a apiBankCurrencyGetRequest struct via the builder pattern


### Return type

[**[]CurrencyInfoInner**](CurrencyInfoInner.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## PersonalClientInfoGet

> UserInfo PersonalClientInfoGet(ctx).XToken(xToken).Execute()

Інформація про клієнта



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "gitea.stuzer.link/stuzer05/go-monobank"
)

func main() {
	xToken := "u3AulkpZFI1lIuGsik6vuPsVWqN7GoWs6o_MO2sdf301" // string | Token для особистого доступу до API

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	resp, r, err := apiClient.DefaultApi.PersonalClientInfoGet(context.Background()).XToken(xToken).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `DefaultApi.PersonalClientInfoGet``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
	// response from `PersonalClientInfoGet`: UserInfo
	fmt.Fprintf(os.Stdout, "Response from `DefaultApi.PersonalClientInfoGet`: %v\n", resp)
}
```

### Path Parameters



### Other Parameters

Other parameters are passed through a pointer to a apiPersonalClientInfoGetRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xToken** | **string** | Token для особистого доступу до API | 

### Return type

[**UserInfo**](UserInfo.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## PersonalStatementAccountFromToGet

> []StatementItemsInner PersonalStatementAccountFromToGet(ctx, account, from, to).XToken(xToken).Execute()

Виписка



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "gitea.stuzer.link/stuzer05/go-monobank"
)

func main() {
	xToken := "xToken_example" // string | Token для особистого доступу до API
	account := "account_example" // string | Ідентифікатор рахунку або банки з переліків Statement list або 0 - дефолтний рахунок.
	from := "1546304461" // string | Початок часу виписки.
	to := "1546306461" // string | Останній час виписки (якщо відсутній, буде використовуватись поточний час). (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	resp, r, err := apiClient.DefaultApi.PersonalStatementAccountFromToGet(context.Background(), account, from, to).XToken(xToken).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `DefaultApi.PersonalStatementAccountFromToGet``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
	// response from `PersonalStatementAccountFromToGet`: []StatementItemsInner
	fmt.Fprintf(os.Stdout, "Response from `DefaultApi.PersonalStatementAccountFromToGet`: %v\n", resp)
}
```

### Path Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
**ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
**account** | **string** | Ідентифікатор рахунку або банки з переліків Statement list або 0 - дефолтний рахунок. | 
**from** | **string** | Початок часу виписки. | 
**to** | **string** | Останній час виписки (якщо відсутній, буде використовуватись поточний час). | 

### Other Parameters

Other parameters are passed through a pointer to a apiPersonalStatementAccountFromToGetRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xToken** | **string** | Token для особистого доступу до API | 




### Return type

[**[]StatementItemsInner**](StatementItemsInner.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## PersonalWebhookPost

> PersonalWebhookPost(ctx).XToken(xToken).SetWebHook(setWebHook).Execute()

Встановлення WebHook



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "gitea.stuzer.link/stuzer05/go-monobank"
)

func main() {
	xToken := "xToken_example" // string | Token для особистого доступу до API
	setWebHook := *openapiclient.NewSetWebHook() // SetWebHook | 

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.DefaultApi.PersonalWebhookPost(context.Background()).XToken(xToken).SetWebHook(setWebHook).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `DefaultApi.PersonalWebhookPost``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters



### Other Parameters

Other parameters are passed through a pointer to a apiPersonalWebhookPostRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xToken** | **string** | Token для особистого доступу до API | 
 **setWebHook** | [**SetWebHook**](SetWebHook.md) |  | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)

